@@ -4,7 +4,11 @@
 #' @inheritParams accepted_names
 #' @template tsn
 #' @examples \dontrun{
+#' # results
 #' other_sources(tsn=182662)
+#' # no results
+#' other_sources(tsn=2085272) 
+#' # get xml
 #' other_sources(tsn=182662, wt = "xml")
 #' }
 other_sources <- function(tsn, wt = "json", raw = FALSE, ...) {
@@ -12,7 +16,7 @@ other_sources <- function(tsn, wt = "json", raw = FALSE, ...) {
   if (raw || wt == "xml") return(out)
   x <- parse_raw(out)$otherSources
   if (inherits(x, "logical") || is.null(x)) {
-    tibble::data_frame()
+    tibble::tibble()
   } else {
     x <- cbind(dr_op(x, "referencefor"), bindlist(x$referenceFor))
     tibble::as_tibble(pick_cols(
