@@ -11,7 +11,7 @@ unacceptability_reason <- function(tsn, wt = "json", raw = FALSE, ...) {
   if (raw || wt == "xml") return(out)
   x <- parse_raw(out)
   if (is.null(x$unacceptReason) || inherits(x$unacceptReason, "logical")) {
-    tibble::data_frame()
+    tibble::tibble()
   } else {
     dr_op(tibble::as_tibble(x), "class")
   }
