@@ -13,7 +13,7 @@ usage <- function(tsn, wt = "json", raw = FALSE, ...) {
   if (raw || wt == "xml") return(out)
   x <- parse_raw(out)
   if (is.null(x$taxonUsageRating) || inherits(x$taxonUsageRating, "logical")) {
-    tibble::data_frame()
+    tibble::tibble()
   } else {
     dr_op(tibble::as_tibble(x), "class")
   }
