@@ -2,4 +2,4 @@ sm <- function(x) suppressMessages(x)
 
 # set up vcr
 library("vcr")
-invisible(vcr::vcr_configure(dir = "../fixtures/vcr_cassettes"))
+invisible(vcr::vcr_configure(dir = "../fixtures"))
